#! /bin/tcsh

#### Making files in AFNI format 
#### COPY"LEFT" by Hang Joon Jo @ NIMH/NIH, 2012
#### Get Data from NITRC website, and then decompress the file.
cd INDI_Lite_NIFTI/cohort1


# Make uniform directory structures
mv sub0015013/session_2/rest_1 sub0015013/session_1/rest_2
rm -r sub0015013/session_2
mv sub0015016/session_2/rest_1 sub0015016/session_1/rest_2
mv sub0015016/session_2/mprage_1 sub0015016/session_1
rm -r sub0015016/session_2
mv sub0015017/session_2/rest_1 sub0015017/session_1/rest_2
rm -r sub0015017/session_2
mv sub0015018/session_2/* sub0015018/session_1
rm -r sub0015018/session_2
mv sub0015019/session_2/rest_1 sub0015019/session_1/rest_2
rm -r sub0015019/session_2
mv sub0015020/session_2/rest_1 sub0015020/session_1/rest_2
mv sub0015020/session_2/rest_2 sub0015020/session_1/rest_3
rm -r sub0015020/session_2
mv sub0015021/session_2/rest_1 sub0015021/session_1/rest_2
rm -r sub0015021/session_2
mv sub0015024/session_2/rest_1 sub0015024/session_1/rest_2
rm -r sub0015024/session_2
mv sub0015063/session_2/rest_1 sub0015063/session_1/rest_2
rm -r sub0015063/session_2
rm -r sub0015067/session_1/mprage_2

### Make data form
# Loop Start
foreach ss ( sub* )
  echo ${ss}
  cd ${ss}

  # Shift mprages to center to shorten registration time
  foreach rr ( session_?/mprage_? )
    cd ${rr}
    3drefit -deoblique mprage.nii.gz
    set aa = `3dAttribute -center mprage.nii.gz`
    set x = `ccalc -$aa[1]`
    set y = `ccalc -$aa[2]`
    set z = `ccalc -$aa[3]`
    3drefit -dxorigin $x -dyorigin $y -dzorigin $z mprage.nii.gz
    cd ../../
  end

  # EPI works
  foreach rr ( session_?/rest_? )
    cd ${rr}
    # Deoblique and Shift center
    3drefit -deoblique rest.nii.gz
    set aa = `3dAttribute -center rest.nii.gz`
    set x = `ccalc -$aa[1]`
    set y = `ccalc -$aa[2]`
    set z = `ccalc -$aa[3]`
    3drefit -dxorigin $x -dyorigin $y -dzorigin $z rest.nii.gz
  end

  cd ../
end

foreach ss ( sub*)
cd ${ss}

 afni_proc.py -subj_id A -script proc.A -scr_overwrite -blocks align tlrc    \
     volreg blur mask regress -copy_anat ./session_?/mprage_?/mprage.nii.gz  \
     -tcat_remove_first_trs 2 -dsets ./session_?/rest_?/rest.nii.gz          \
     -align_opts_aea -cost lpc+ZZ -giant_move \
     -tlrc_base MNI_avg152T1+tlrc -volreg_align_to third -volreg_align_e2a   \
     -volreg_tlrc_warp -volreg_warp_dxyz 3.0 -blur_size 6.0                  \
     -regress_apply_mot_types demean deriv -regress_motion_per_run           \
     -mask_segment_anat yes -regress_ROI brain WM CSF -regress_run_clustsim  \
     no -regress_opts_3dD  -regress_est_blur_epits                    \
     -regress_est_blur_errts -execute

 afni_proc.py -subj_id A.cen -script proc.A.cen -scr_overwrite -blocks align \
     tlrc volreg blur mask regress -copy_anat                                \
     ./session_?/mprage_?/mprage.nii.gz -tcat_remove_first_trs 2 -dsets      \
     ./session_?/rest_?/rest.nii.gz           \
     -align_opts_aea -cost lpc+ZZ -giant_move -tlrc_base MNI_avg152T1+tlrc   \
     -volreg_align_to third -volreg_align_e2a -volreg_tlrc_warp              \
     -volreg_warp_dxyz 3.0 -blur_size 6.0 -regress_censor_motion 0.25        \
     -regress_apply_mot_types demean deriv -regress_motion_per_run           \
     -mask_segment_anat yes -regress_ROI brain WM CSF -regress_run_clustsim  \
     no -regress_opts_3dD -regress_est_blur_epits                    \
     -regress_est_blur_errts -execute

  mkdir B.results
  cd B.results
  3dDeconvolve -input ../A.results/pb02.A.r*.blur+tlrc.HEAD \
    -ortvec ../A.results/ROI.brain_rall.1D ROI.brain \
    -ortvec ../A.results/ROI.WM_rall.1D ROI.WM \
    -ortvec ../A.results/ROI.CSF_rall.1D ROI.CSF \
    -polort 3 \
    -fout -tout -x1D X.xmat.1D -xjpeg X.jpg \
    -fitts fitts.B \
    -errts errts.B \
    -bucket stats.B
  cd ..

  mkdir B.cen.results
  cd B.cen.results
  3dDeconvolve -input ../A.cen.results/pb02.A.cen.r*.blur+tlrc.HEAD \
    -censor ../A.cen.results/motion_A.cen_censor.1D \
    -ortvec ../A.cen.results/ROI.brain_rall.1D ROI.brain \
    -ortvec ../A.cen.results/ROI.WM_rall.1D ROI.WM \
    -ortvec ../A.cen.results/ROI.CSF_rall.1D ROI.CSF \
    -polort 3 \
    -fout -tout -x1D X.xmat.1D -xjpeg X.jpg \
    -x1D_uncensored ../A.cen.results/X.nocensor.xmat.1D \
    -fitts fitts.B.cen \
    -errts errts.B.cen \
    -bucket stats.B.cen
  cd ..

  afni_proc.py -subj_id C -script proc.C -scr_overwrite -blocks align tlrc    \
     volreg blur mask regress -copy_anat ./session_?/mprage_?/mprage.nii.gz  \
     -tcat_remove_first_trs 2 -dsets ./session_?/rest_?/rest.nii.gz          \
     -align_opts_aea -cost lpc+ZZ -giant_move \
     -tlrc_base MNI_avg152T1+tlrc -volreg_align_to third -volreg_align_e2a   \
     -volreg_tlrc_warp -volreg_warp_dxyz 3.0 -blur_size 6.0                  \
     -regress_apply_mot_types demean deriv -regress_motion_per_run           \
     -mask_segment_anat yes -regress_run_clustsim  no -regress_opts_3dD \
     -regress_est_blur_epits                    \
     -regress_est_blur_errts -execute

  afni_proc.py -subj_id C.cen -script proc.C.cen -scr_overwrite -blocks align \
     tlrc volreg blur mask regress -copy_anat                                \
     ./session_?/mprage_?/mprage.nii.gz -tcat_remove_first_trs 2 -dsets      \
     ./session_?/rest_?/rest.nii.gz            \
     -align_opts_aea -cost lpc+ZZ -giant_move -tlrc_base MNI_avg152T1+tlrc   \
     -volreg_align_to third -volreg_align_e2a -volreg_tlrc_warp              \
     -volreg_warp_dxyz 3.0 -blur_size 6.0 -regress_censor_motion 0.25        \
     -regress_apply_mot_types demean deriv -regress_motion_per_run           \
     -mask_segment_anat yes -regress_run_clustsim  \
     no -regress_opts_3dD -regress_est_blur_epits                    \
     -regress_est_blur_errts -execute

  afni_proc.py -subj_id D -script proc.D -scr_overwrite -blocks despike align tlrc    \
     volreg blur mask regress -copy_anat ./session_?/mprage_?/mprage.nii.gz  \
     -tcat_remove_first_trs 2 -dsets ./session_?/rest_?/rest.nii.gz          \
     -align_opts_aea -cost lpc+ZZ -giant_move \
     -tlrc_base MNI_avg152T1+tlrc -volreg_align_to third -volreg_align_e2a   \
     -volreg_tlrc_warp -volreg_warp_dxyz 3.0 -blur_size 6.0                  \
     -regress_apply_mot_types demean deriv -regress_motion_per_run           \
     -mask_segment_anat yes -regress_run_clustsim  no -regress_opts_3dD \
     -regress_est_blur_epits                    \
     -regress_est_blur_errts -execute

  afni_proc.py -subj_id D.cen -script proc.D.cen -scr_overwrite -blocks despike align \
     tlrc volreg blur mask regress -copy_anat                                \
     ./session_?/mprage_?/mprage.nii.gz -tcat_remove_first_trs 2 -dsets      \
     ./session_?/rest_?/rest.nii.gz          \
     -align_opts_aea -cost lpc+ZZ -giant_move -tlrc_base MNI_avg152T1+tlrc   \
     -volreg_align_to third -volreg_align_e2a -volreg_tlrc_warp              \
     -volreg_warp_dxyz 3.0 -blur_size 6.0 -regress_censor_motion 0.25        \
     -regress_apply_mot_types demean deriv -regress_motion_per_run           \
     -mask_segment_anat yes -regress_run_clustsim  \
     no -regress_opts_3dD -regress_est_blur_epits                    \
     -regress_est_blur_errts -execute

  cd ..
end


## Motion censoring and bandpass filtering should be simultaneously done by afni_proc.py. 
##  However, this process was separated in this study
##  since many subjects have shorter time series than the minimum DOF for regression.

foreach ss (sub*)
  cd ${ss}
  foreach cc ( A B C D )
    3dBandpass -prefix ${cc}.results/errts.${cc}.bp -notrans -nodetrend -band 0.009 0.08 ${cc}.results/errts.${cc}+tlrc
    3dBandpass -prefix ${cc}.cen.results/errts.${cc}.cen.bp -notrans -nodetrend -band 0.009 0.08 ${cc}.cen.results/errts.${cc}.cen+tlrc
  cd ..
end


## Get Corr. Matrix

foreach cc ( A B C D )

  foreach ss (sub*)
    cd ${ss}
    foreach k (`count -digits 1 0 263`)
      set xx = `1dcat ../../../x_correct.1D'{'$k'}'`
      set yy = `1dcat ../../../y_correct.1D'{'$k'}'`
      set zz = `1dcat ../../../z.1D'{'$k'}'`

      3dmaskave -quiet -xball ${xx} ${yy} ${zz} 5 ./${cc}.results/errts.${cc}.bp+tlrc > ./${cc}.results/temp1
      1dtranspose ./${cc}.results/temp1 > ./${cc}.results/temp2
    cat ./${cc}.results/temp2 >> ./${cc}.results/TS_ALL.slow.1D

      3dmaskave -quiet -xball ${xx} ${yy} ${zz} 5 ./${cc}.cen.results/errts.${cc}.cen.bp+tlrc > ./${cc}.cen.results/temp1
      1dtranspose ./${cc}.cen.results/temp1 > ./${cc}.cen.results/temp2
      cat ./${cc}.cen.results/temp2 >> ./${cc}.cen.results/TS_ALL.slow.1D
    end

    1ddot -terse -okzero -dem ./${cc}.results/TS_ALL.slow.1D\' > ./${cc}.results/TS_ALL.corr.1D
    1ddot -terse -okzero -dem ./${cc}.cen.results/TS_ALL.slow.1D\' > ./${cc}.cen.results/TS_ALL.corr.1D

    cd ../
  end

end
